summaryrefslogtreecommitdiffstats
path: root/krfb/srvloc/kserviceregistry.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /krfb/srvloc/kserviceregistry.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krfb/srvloc/kserviceregistry.h')
-rw-r--r--krfb/srvloc/kserviceregistry.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/krfb/srvloc/kserviceregistry.h b/krfb/srvloc/kserviceregistry.h
index a1c439ae..8cd965e6 100644
--- a/krfb/srvloc/kserviceregistry.h
+++ b/krfb/srvloc/kserviceregistry.h
@@ -25,9 +25,9 @@
#ifndef __KSERVICEREGISTRY_H
#define __KSERVICEREGISTRY_H
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqmap.h>
class KServiceRegistryPrivate;
@@ -78,7 +78,7 @@ class KServiceRegistryPrivate;
* <pre>
* KServiceRegistry ksr;
* KInetAddress kia = KInetAddress->getLocalAddress();
- * ksr.registerService(QString("service:remotedesktop.kde:vnc://%1:0").arg(kia->nodeName()),
+ * ksr.registerService(TQString("service:remotedesktop.kde:vnc://%1:0").arg(kia->nodeName()),
* "(type=shared)");
* delete kia;
* </pre>
@@ -91,10 +91,10 @@ class KServiceRegistry {
/**
* Creates a new service registration instance for the given
* language.
* @param lang the language as two letter code, or QString::null for the
* system default
*/
- KServiceRegistry(const QString &lang = QString::null);
+ KServiceRegistry(const TQString &lang = TQString::null);
virtual ~KServiceRegistry();
/**
@@ -110,17 +110,17 @@ class KServiceRegistry {
* @param map the items of this list will be converted
* @return the comma-separated list
*/
- static QString createCommaList(const QStringList &values);
+ static TQString createCommaList(const TQStringList &values);
/**
* Encodes an QString for use as a attribute value. This will escape
* all characters that are not allowed. This method is only available
* when a SLP library is available, otherwise it will return the
* given value.
* @param value the value string to encode
* @return the encoded value string
*/
- static QString encodeAttributeValue(const QString &value);
+ static TQString encodeAttributeValue(const TQString &value);
/**
* Registers the given service.
@@ -132,8 +132,8 @@ class KServiceRegistry {
* @return true if successful, false otherwise. False usually means that no
* SA daemon (slpd) is running.
*/
- bool registerService(const QString &serviceURL,
- QString attributes = QString::null,
+ bool registerService(const TQString &serviceURL,
+ TQString attributes = TQString::null,
unsigned short lifetime = 0);
/**
@@ -144,15 +144,15 @@ class KServiceRegistry {
* @return true if successful, false otherwise. False usually means that no
* SA daemon is running (slpd).
*/
- bool registerService(const QString &serviceURL,
- QMap<QString,QString> attributes,
+ bool registerService(const TQString &serviceURL,
+ TQMap<TQString,TQString> attributes,
unsigned short lifetime = 0);
/**
* Unregisters the given service.
* @param serviceURL the service URL to unregister
*/
- void unregisterService(const QString &serviceURL);
+ void unregisterService(const TQString &serviceURL);
private:
KServiceRegistryPrivate *d;
@@ -91,10 +91,10 @@ class KServiceRegistry {
* Creates a new service registration instance for the given
* language.
- * @param lang the language as two letter code, or QString::null for the
+ * @param lang the language as two letter code, or TQString::null for the
* system default
*/
@@ -110,17 +110,17 @@ class KServiceRegistry {
/**
- * Encodes an QString for use as a attribute value. This will escape
+ * Encodes an TQString for use as a attribute value. This will escape
* all characters that are not allowed. This method is only available
* when a SLP library is available, otherwise it will return the